"""Functions used to stylize matplotlib stuff."""
from typing import Union

import matplotlib as mpl
import matplotlib.pyplot as plt


def make_plots_scientific(fs: Union[float, int] = 12):
    """Make the fonts in all plots more scientific.
    Params:
        fs (str, float): The fontsize to use.
    """
    plt.rc('text', usetex=True)
    mpl.rcParams['font.family'] = 'serif'
    mpl.rcParams['font.serif'] = 'cmr10'  # Computer Modern Roman
    mpl.rcParams['font.size'] = fs  # Adjust the font size as needed


def make_colors_gg() -> list:
    """Sets the colors to the ggplot colors.
    Returns:
        A list of the hex codes for the colors"""
    plt.style.use('ggplot')
    colors = plt.rcParams['axes.prop_cycle'].by_key()['color']
    plt.style.use('default')
    mpl.rcParams['axes.prop_cycle'] = mpl.cycler(color=colors)

    return colors



import os

import pip
from setuptools import find_packages, setup

setup(
    name='Moby_Land',
    version='0.2.0',
    author='Adam Boesky',
    author_email='apboesky@gmail.com',
    description='A place for all of Adam\' gadgets.',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.11',
    install_requires=[],
)

# To republish:
# 1. bump version nuber
# 2. python setup.py sdist
# 3. twine upload dist/*
